@@ -1,4 +1,4 @@
-/* $Header: /src/pub/tcsh/ed.screen.c,v 3.56 2004/11/21 04:38:03 christos Exp $ */
+/* $Header: /src/pub/tcsh/ed.screen.c,v 3.63 2005/01/18 20:43:30 christos Exp $ */
 /*
  * ed.screen.c: Editor/termcap-curses interface
  */
@@ -32,7 +32,7 @@
  */
 #include "sh.h"
 
-RCSID("$Id: ed.screen.c,v 3.56 2004/11/21 04:38:03 christos Exp $")
+RCSID("$Id: ed.screen.c,v 3.63 2005/01/18 20:43:30 christos Exp $")
 
 #include "ed.h"
 #include "tc.h"
@@ -165,7 +165,7 @@ static struct {
 #define T_str   38
 static struct termcapstr {
     const char   *name;
-    char   *long_name;
+    const char   *long_name;
     char   *str;
 } tstr[T_str + 1];
 
@@ -179,7 +179,7 @@ static struct termcapstr {
 #define T_val	6
 static struct termcapval {
     const char   *name;
-    char   *long_name;
+    const char   *long_name;
     int     val;
 } tval[T_val + 1];
 
@@ -349,7 +349,7 @@ terminit()
  * No Wrap         no      --              yes             yes
  */
 
-static bool me_all = 0;		/* does two or more of the attributes use me */
+static int me_all = 0;		/* does two or more of the attributes use me */
 
 static	void	ReBufferDisplay	__P((void));
 static	void	TCalloc		__P((struct termcapstr *, char *)); 
@@ -422,33 +422,36 @@ TCalloc(t, cap)
 
 /*ARGSUSED*/
 void
-TellTC(what)
-    const char   *what;
+TellTC()
 {
     struct termcapstr *t;
+    char *s;
 
-    USE(what);
     xprintf(CGETS(7, 1, "\n\tTcsh thinks your terminal has the\n"));
     xprintf(CGETS(7, 2, "\tfollowing characteristics:\n\n"));
     xprintf(CGETS(7, 3, "\tIt has %d columns and %d lines\n"),
 	    Val(T_co), Val(T_li));
-    xprintf(CGETS(7, 4, "\tIt has %s meta key\n"), T_HasMeta ?
-	    CGETS(7, 5, "a") : CGETS(7, 6, "no"));
-    xprintf(CGETS(7, 7, "\tIt can%s use tabs\n"), T_Tabs ?
-	    "" : CGETS(7, 8, " not"));
-    xprintf(CGETS(7, 9, "\tIt %s automatic margins\n"),
-		    (T_Margin&MARGIN_AUTO)?
-		    CGETS(7, 10, "has"):
-		    CGETS(7, 11, "does not have"));
-    if (T_Margin & MARGIN_AUTO)
-	xprintf(CGETS(7, 12, "\tIt %s magic margins\n"),
-			(T_Margin & MARGIN_MAGIC) ?
-			CGETS(7, 10, "has"):
-			CGETS(7, 11, "does not have"));
-
-    for (t = tstr; t->name != NULL; t++)
-	xprintf("\t%36s (%s) == %s\n", t->long_name, t->name,
-		t->str && *t->str ? t->str : CGETS(7, 13, "(empty)"));
+    s = strsave(T_HasMeta ? CGETS(7, 5, "a") : CGETS(7, 6, "no"));
+    xprintf(CGETS(7, 4, "\tIt has %s meta key\n"), s);
+    xfree(s);
+    s = strsave(T_Tabs ? "" : CGETS(7, 8, " not"));
+    xprintf(CGETS(7, 7, "\tIt can%s use tabs\n"), s);
+    xfree(s);
+    s = strsave((T_Margin&MARGIN_AUTO) ?
+		CGETS(7, 10, "has") : CGETS(7, 11, "does not have"));
+    xprintf(CGETS(7, 9, "\tIt %s automatic margins\n"), s);
+    xfree(s);
+    if (T_Margin & MARGIN_AUTO) {
+        s = strsave((T_Margin & MARGIN_MAGIC) ?
+			CGETS(7, 10, "has") : CGETS(7, 11, "does not have"));
+	xprintf(CGETS(7, 12, "\tIt %s magic margins\n"), s);
+	xfree(s);
+    }
+    for (t = tstr; t->name != NULL; t++) {
+        s = strsave(t->str && *t->str ? t->str : CGETS(7, 13, "(empty)"));
+	xprintf("\t%36s (%s) == %s\n", t->long_name, t->name, s);
+	xfree(s);
+    }
     xputchar('\n');
 }
 
@@ -457,8 +460,8 @@ static void
 ReBufferDisplay()
 {
     int i;
-    eChar **b;
-    eChar **bufp;
+    Char **b;
+    Char **bufp;
 
     b = Display;
     Display = NULL;
@@ -476,14 +479,14 @@ ReBufferDisplay()
     }
     TermH = Val(T_co);
     TermV = (INBUFSIZE * 4) / TermH + 1;
-    b = (eChar **) xmalloc((size_t) (sizeof(*b) * (TermV + 1)));
+    b = (Char **) xmalloc((size_t) (sizeof(*b) * (TermV + 1)));
     for (i = 0; i < TermV; i++)
-	b[i] = (eChar *) xmalloc((size_t) (sizeof(*b[i]) * (TermH + 1)));
+	b[i] = (Char *) xmalloc((size_t) (sizeof(*b[i]) * (TermH + 1)));
     b[TermV] = NULL;
     Display = b;
-    b = (eChar **) xmalloc((size_t) (sizeof(*b) * (TermV + 1)));
+    b = (Char **) xmalloc((size_t) (sizeof(*b) * (TermV + 1)));
     for (i = 0; i < TermV; i++)
-	b[i] = (eChar *) xmalloc((size_t) (sizeof(*b[i]) * (TermH + 1)));
+	b[i] = (Char *) xmalloc((size_t) (sizeof(*b[i]) * (TermH + 1)));
     b[TermV] = NULL;
     Vdisplay = b;
 }
@@ -775,7 +778,7 @@ EchoTC(v)
     }
 }
 
-bool    GotTermCaps = 0;
+int    GotTermCaps = 0;
 
 static struct {
     Char   *name;
@@ -998,7 +1001,7 @@ static Char cur_atr = 0;	/* current attributes */
 
 void
 SetAttributes(atr)
-    int     atr;
+    Char     atr;
 {
     atr &= ATTRIBUTES;
     if (atr != cur_atr) {
@@ -1094,17 +1097,12 @@ MoveToLine(where)		/* move to line <where> (first line == 0) */
 	    if ((T_Margin & MARGIN_AUTO) && Display[CursorV][0] != '\0') {
 		size_t h;
 
-		for (h = TermH - 1; h > 0 && Display[CursorV][h] == CHAR_ERR;
+		for (h = TermH - 1; h > 0 && Display[CursorV][h] == CHAR_DBWIDTH;
 		     h--)
 		    ;
 		/* move without newline */
 		MoveToChar(h);
-#ifdef DSPMBYTE
-		if (h > 0 && Ismbyte2(Display[CursorV][CursorH]))
-		    MoveToChar(h - 1);
-#else
 		so_write(&Display[CursorV][CursorH], TermH - CursorH); /* updates CursorH/V*/
-#endif
 		del--;
 	    }
 	    else {
@@ -1169,13 +1167,9 @@ mc_again:
 		(void) tputs(tgoto(Str(T_RI), del, del), del, PUTPURE);
 	    else {
 		/* if I can do tabs, use them */
-		if (T_Tabs
-#ifdef DSPMBYTE
-		    && !_enable_mbdisp
-#endif /* DSPMBYTE */
-		) {
+		if (T_Tabs) {
 		    if ((CursorH & 0370) != (where & ~0x7)
-			&& Display[CursorV][where & ~0x7] != CHAR_ERR) {
+			&& Display[CursorV][where & ~0x7] != CHAR_DBWIDTH) {
 			/* if not within tab stop */
 			for (i = (CursorH & 0370); i < (where & ~0x7); i += 8)
 			    (void) putraw('\t');	/* then tab over */
@@ -1214,7 +1208,7 @@ mc_again:
 
 void
 so_write(cp, n)
-    eChar *cp;
+    Char *cp;
     int n;
 {
     if (n <= 0)
@@ -1229,17 +1223,14 @@ so_write(cp, n)
     }
 
     do {
-	if (*cp != CHAR_ERR) {
+	if (*cp != CHAR_DBWIDTH) {
 	    if (*cp & LITERAL) {
 		Char   *d;
-		
 #ifdef DEBUG_LITERAL
-		xprintf("so: litnum %d, litptr %x\r\n",
-			(int)(*cp & CHAR), litptr[*cp & CHAR]);
+		xprintf("so: litnum %d\r\n", (int)(*cp & ~LITERAL));
 #endif /* DEBUG_LITERAL */
-		for (d = litptr[*cp & CHAR]; *d & LITERAL; d++)
-		    (void) putwraw(*d & CHAR);
-		(void) putwraw(*d);
+		for (d = litptr + (*cp & ~LITERAL) * LIT_FACTOR; *d; d++)
+		    (void) putwraw(*d);
 	    }
 	    else
 		(void) putwraw(*cp);
@@ -1254,15 +1245,10 @@ so_write(cp, n)
 	    CursorV++;
 	    if (T_Margin & MARGIN_MAGIC) {
 		/* force the wrap to avoid the "magic" situation */
-		eChar c;
+		Char c;
 		if ((c = Display[CursorV][CursorH]) != '\0') {
 		    so_write(&c, 1);
-#ifdef DSPMBYTE
-		    if (CursorH > 0 && (c = Display[CursorV][CursorH]) != 0)
-			if (Ismbyte2(c))
-			    so_write(&c, 1);
-#endif
-		    while(Display[CursorV][CursorH] == CHAR_ERR)
+		    while(Display[CursorV][CursorH] == CHAR_DBWIDTH)
 			CursorH++;
 		}
 		else {
@@ -1319,7 +1305,7 @@ DeleteChars(num)		/* deletes <num> characters */
 
 void
 Insert_write(cp, num)		/* Puts terminal in insert character mode, */
-    eChar *cp;
+    Char *cp;
     int num;		/* or inserts num characters in the line */
 {
     if (num <= 0)
@@ -1650,7 +1636,6 @@ ChangeSize(lins, cols)
 	if ((tptr = getenv("TERMCAP")) != NULL) {
 	    /* Leave 64 characters slop in case we enlarge the termcap string */
 	    Char    termcap[1024+64], backup[1024+64], *ptr;
-	    int     i;
 
 	    ptr = str2short(tptr);
 	    (void) Strncpy(termcap, ptr, 1024);
@@ -1665,11 +1650,11 @@ ChangeSize(lins, cols)
 		(void) Strcpy(backup, termcap);
 	    }
 	    else {
-		i = (int) (ptr - termcap + Strlen(buf));
-		(void) Strncpy(backup, termcap, (size_t) i);
-		backup[i] = '\0';
+		size_t len = (ptr - termcap) + Strlen(buf);
+		(void) Strncpy(backup, termcap, len);
+		backup[len] = '\0';
 		(void) Itoa(Val(T_co), buf, 0, 0);
-		(void) Strcat(backup + i, buf);
+		(void) Strcat(backup + len, buf);
 		ptr = Strchr(ptr, ':');
 		(void) Strcat(backup, ptr);
 	    }
@@ -1683,9 +1668,9 @@ ChangeSize(lins, cols)
 		(void) Strcpy(termcap, backup);
 	    }
 	    else {
-		i = (int) (ptr - backup + Strlen(buf));
-		(void) Strncpy(termcap, backup, (size_t) i);
-		termcap[i] = '\0';
+		size_t len = (ptr - backup) + Strlen(buf);
+		(void) Strncpy(termcap, backup, len);
+		termcap[len] = '\0';
 		(void) Itoa(Val(T_li), buf, 0, 0);
 		(void) Strcat(termcap, buf);
 		ptr = Strchr(ptr, ':');
