@@ -1,4 +1,4 @@
-/* $Header: /src/pub/tcsh/sh.c,v 3.117 2004/11/20 18:25:25 christos Exp $ */
+/* $Header: /src/pub/tcsh/sh.c,v 3.123 2005/03/21 21:26:36 kim Exp $ */
 /*
  * sh.c: Main shell routines
  */
@@ -39,14 +39,14 @@ char    copyright[] =
  All rights reserved.\n";
 #endif /* not lint */
 
-RCSID("$Id: sh.c,v 3.117 2004/11/20 18:25:25 christos Exp $")
+RCSID("$Id: sh.c,v 3.123 2005/03/21 21:26:36 kim Exp $")
 
 #include "tc.h"
 #include "ed.h"
 #include "tw.h"
 
-extern bool MapsAreInited;
-extern bool NLSMapsAreInited;
+extern int MapsAreInited;
+extern int NLSMapsAreInited;
 
 /*
  * C Shell
@@ -93,7 +93,7 @@ int do_logout = 0;
 #endif /* TESLA */
 
 
-bool    use_fork = 0;		/* use fork() instead of vfork()? */
+int    use_fork = 0;		/* use fork() instead of vfork()? */
 
 /*
  * Magic pointer values. Used to specify other invalid conditions aside
@@ -104,20 +104,20 @@ Char    *INVPTR = &INVCHAR;
 Char    **INVPPTR = &INVPTR;
 
 static int     nofile = 0;
-static bool    reenter = 0;
-static bool    nverbose = 0;
-static bool    nexececho = 0;
-static bool    quitit = 0;
-static bool    rdirs = 0;
-bool    fast = 0;
-static bool    batch = 0;
-static bool    mflag = 0;
-static bool    prompt = 1;
+static int    reenter = 0;
+static int    nverbose = 0;
+static int    nexececho = 0;
+static int    quitit = 0;
+static int    rdirs = 0;
+int    fast = 0;
+static int    batch = 0;
+static int    mflag = 0;
+static int    prompt = 1;
 int     enterhist = 0;
-bool    tellwhat = 0;
+int    tellwhat = 0;
 time_t  t_period;
 Char  *ffile = NULL;
-bool	dolzero = 0;
+int	dolzero = 0;
 int	insource = 0;
 int	exitset = 0;
 static time_t  chktim;		/* Time mail last checked */
@@ -144,10 +144,10 @@ struct saved_state {
     Char	 *alvecp;
     Char	**alvec;
     int		  onelflg;
-    bool	  enterhist;
+    int	  enterhist;
     Char	**argv;
     Char	  HIST;
-    bool	  cantell;
+    int	  cantell;
     struct Bin	  B;
     /* These keep signal state and setjump state */
 #ifdef BSDSIGS
@@ -159,12 +159,12 @@ struct saved_state {
 
 static	int		  srccat	__P((Char *, Char *));
 #ifndef WINNT_NATIVE
-static	int		  srcfile	__P((const char *, bool, int, Char **));
+static	int		  srcfile	__P((const char *, int, int, Char **));
 #else
-int		  srcfile	__P((const char *, bool, int, Char **));
+int		  srcfile	__P((const char *, int, int, Char **));
 #endif /*WINNT_NATIVE*/
-static	sigret_t	  phup		__P((int));
-static	void		  srcunit	__P((int, bool, int, Char **));
+static	RETSIGTYPE	  phup		__P((int));
+static	void		  srcunit	__P((int, int, int, Char **));
 static	void		  mailchk	__P((void));
 #ifndef _PATH_DEFPATH
 static	Char	 	**defaultpath	__P((void));
@@ -211,10 +211,9 @@ main(argc, argv)
     nlsinit();
 
 #ifdef MALLOC_TRACE
-     mal_setstatsfile(fdopen(dup2(open("/tmp/tcsh.trace", 
-				       O_WRONLY|O_CREAT|O_LARGEFILE, 0666), 25),
-				       "w"));
-     mal_trace(1);
+    mal_setstatsfile(fdopen(dmove(open("/tmp/tcsh.trace", 
+	O_WRONLY|O_CREAT|O_LARGEFILE, 0666), 25), "w"));
+    mal_trace(1);
 #endif /* MALLOC_TRACE */
 
 #if !(defined(BSDTIMES) || defined(_SEQUENT_)) && defined(POSIX)
@@ -805,6 +804,11 @@ main(argc, argv)
 	xprintf("%S\n", varval(STRversion));
 	xexit(0);
     }
+    if (argc > 1 && strcmp(argv[1], "--help") == 0) {
+	xprintf("%S\n\n", varval(STRversion));
+	xprintf(CGETS(11, 8, HELP_STRING));
+	xexit(0);
+    }
     /*
      * Process the arguments.
      * 
@@ -1473,7 +1477,7 @@ int
 #endif /*WINNT_NATIVE*/
 srcfile(f, onlyown, flag, av)
     const char   *f;
-    bool    onlyown;
+    int    onlyown;
     int flag;
     Char **av;
 {
@@ -1658,7 +1662,7 @@ st_restore(st, av)
 static void
 srcunit(unit, onlyown, hflg, av)
     int unit;
-    bool    onlyown;
+    int    onlyown;
     int hflg;
     Char **av;
 {
@@ -1791,7 +1795,7 @@ exitstat()
 /*
  * in the event of a HUP we want to save the history
  */
-static  sigret_t
+static RETSIGTYPE
 phup(snum)
 int snum;
 {
@@ -1860,9 +1864,6 @@ int snum;
 #endif /* POSIXJOBS */
 
     xexit(snum);
-#ifndef SIGVOID
-    return (snum);
-#endif
 }
 
 static Char   *jobargv[2] = {STRjobs, 0};
@@ -1876,10 +1877,7 @@ static Char   *jobargv[2] = {STRjobs, 0};
  */
 int     just_signaled;		/* bugfix by Michael Bloom (mg@ttidca.TTI.COM) */
 
-#ifdef SIGVOID
-/*ARGSUSED*/
-#endif
-sigret_t
+RETSIGTYPE
 pintr(snum)
 int snum;
 {
@@ -1890,14 +1888,11 @@ int snum;
 #endif /* UNRELSIGS */
     just_signaled = 1;
     pintr1(1);
-#ifndef SIGVOID
-    return (snum);
-#endif
 }
 
 void
 pintr1(wantnl)
-    bool    wantnl;
+    int    wantnl;
 {
     Char **v;
 #ifdef BSDSIGS
@@ -1938,9 +1933,9 @@ pintr1(wantnl)
     (void) sigrelse(SIGCHLD);
 #endif
     drainoline();
-#if !defined(_VMS_POSIX) && !defined(WINNT_NATIVE)
+#ifdef HAVE_GETPWENT
     (void) endpwent();
-#endif /* !_VMS_POSIX && !WINNT_NATIVE */
+#endif
 
     /*
      * If we have an active "onintr" then we search for the label. Note that if
@@ -1993,7 +1988,7 @@ pintr1(wantnl)
 static struct command *savet = NULL;
 void
 process(catch)
-    bool    catch;
+    int    catch;
 {
     jmp_buf_t osetexit;
     /* PWP: This might get nuked my longjmp so don't make it a register var */
@@ -2207,7 +2202,7 @@ dosource(t, c)
     struct command *c;
 {
     Char *f;
-    bool    hflg = 0;
+    int    hflg = 0;
     char    buf[BUFSIZE];
 
     USE(c);
@@ -2266,7 +2261,7 @@ mailchk()
     time_t  t;
     int     intvl, cnt;
     struct stat stb;
-    bool    new;
+    int    new;
 
     v = adrof(STRmail);
     if (v == NULL || v->vec == NULL)
@@ -2336,16 +2331,18 @@ mailchk()
 			mailcount, filename);
 	}
 	else {
+	    char *type;
+	    
 	    if (stb.st_size == 0 || stb.st_atime > stb.st_mtime ||
 		(stb.st_atime <= chktim && stb.st_mtime <= chktim) ||
 		(loginsh && !new))
 		continue;
+	    type = strsave(new ? CGETS(11, 6, "new ") : "");
 	    if (cnt == 1)
-		xprintf(CGETS(11, 5, "You have %smail.\n"),
-			new ? CGETS(11, 6, "new ") : "");
+		xprintf(CGETS(11, 5, "You have %smail.\n"), type);
 	    else
-	        xprintf(CGETS(11, 7, "You have %smail in %s.\n"),
-			new ? CGETS(11, 6, "new ") : "", filename);
+	        xprintf(CGETS(11, 7, "You have %smail in %s.\n"), type, filename);
+	    xfree(type);
 	}
     }
     chktim = t;
