@@ -1,4 +1,4 @@
-/* $Header: /src/pub/tcsh/sh.hist.c,v 3.30 2004/08/04 17:12:29 christos Exp $ */
+/* $Header: /src/pub/tcsh/sh.hist.c,v 3.33 2004/12/25 21:15:07 christos Exp $ */
 /*
  * sh.hist.c: Shell history expansions and substitutions
  */
@@ -32,15 +32,15 @@
  */
 #include "sh.h"
 
-RCSID("$Id: sh.hist.c,v 3.30 2004/08/04 17:12:29 christos Exp $")
+RCSID("$Id: sh.hist.c,v 3.33 2004/12/25 21:15:07 christos Exp $")
 
 #include "tc.h"
 
-extern bool histvalid;
+extern int histvalid;
 extern Char histline[];
 Char HistLit = 0;
 
-static	bool	heq	__P((struct wordent *, struct wordent *));
+static	int	heq	__P((struct wordent *, struct wordent *));
 static	void	hfree	__P((struct Hist *));
 static	void	dohist1	__P((struct Hist *, int *, int));
 static	void	phist	__P((struct Hist *, int));
@@ -60,7 +60,7 @@ static	void	phist	__P((struct Hist *, int));
 void
 savehist(sp, mflg)
     struct wordent *sp;
-    bool mflg;
+    int mflg;
 {
     struct Hist *hp, *np;
     int histlen = 0;
@@ -90,7 +90,7 @@ savehist(sp, mflg)
 	    hp = np;
 }
 
-static bool
+static int
 heq(a0, b0)
     struct wordent *a0, *b0;
 {
@@ -113,8 +113,8 @@ struct Hist *
 enthist(event, lp, docopy, mflg)
     int     event;
     struct wordent *lp;
-    bool    docopy;
-    bool    mflg;
+    int    docopy;
+    int    mflg;
 {
     struct Hist *p = NULL, *pp = &Histlist;
     int n, r;
@@ -295,7 +295,7 @@ dohist1(hp, np, hflg)
     struct Hist *hp;
     int    *np, hflg;
 {
-    bool    print = (*np) > 0;
+    int    print = (*np) > 0;
 
     for (; hp != 0; hp = hp->Hnext) {
 	(*np)--;
@@ -373,21 +373,16 @@ fmthist(fmt, ptr, buf, bufsiz)
 	    (void) sprlex(ibuf, sizeof(ibuf) / sizeof(Char), &hp->Hlex);
 	    p = buf;
 	    ip = ibuf;
-#ifdef WIDE_STRINGS
 	    do {
 	        char xbuf[MB_LEN_MAX];
 		size_t len;
 
 		len = one_wctomb(xbuf, CHAR & *ip);
-		if ((size_t)((p - xbuf) + len) >= bufsiz)
+		if ((size_t)((p - buf) + len) >= bufsiz)
 		    break;
 		memcpy(p, xbuf, len);
 		p += len;
 	    } while ((CHAR & *ip++) != 0);
-#else	    
-	    while (p < buf + bufsiz - 1 && (*p++ = (CHAR & *ip++)) != '\0')
-		continue;
-#endif
 	    if (p <= buf + bufsiz - 1)
 	        *p = '\0';
 	}
@@ -472,7 +467,7 @@ rechist(fname, ref)
 void
 loadhist(fname, mflg)
     Char *fname;
-    bool mflg;
+    int mflg;
 {
     static Char   *loadhist_cmd[] = {STRsource, NULL, NULL, NULL};
     loadhist_cmd[1] = mflg ? STRmm : STRmh;
