@@ -1,4 +1,4 @@
-/* $Header: /src/pub/tcsh/sh.proc.c,v 3.83 2004/08/04 17:12:30 christos Exp $ */
+/* $Header: /src/pub/tcsh/sh.proc.c,v 3.90 2005/03/03 19:57:07 kim Exp $ */
 /*
  * sh.proc.c: Job manipulations
  */
@@ -32,7 +32,7 @@
  */
 #include "sh.h"
 
-RCSID("$Id: sh.proc.c,v 3.83 2004/08/04 17:12:30 christos Exp $")
+RCSID("$Id: sh.proc.c,v 3.90 2005/03/03 19:57:07 kim Exp $")
 
 #include "ed.h"
 #include "tc.h"
@@ -47,9 +47,9 @@ RCSID("$Id: sh.proc.c,v 3.83 2004/08/04 17:12:30 christos Exp $")
 # define HZ 16
 #endif /* aiws */
 
-#if defined(_BSD) || (defined(IRIS4D) && __STDC__) || defined(__lucid) || defined(linux)
+#if defined(_BSD) || (defined(IRIS4D) && __STDC__) || defined(__lucid) || defined(linux) || defined(__GNU__) || defined(__GLIBC__)
 # define BSDWAIT
-#endif /* _BSD || (IRIS4D && __STDC__) || __lucid || linux */
+#endif /* _BSD || (IRIS4D && __STDC__) || __lucid || glibc */
 #ifndef WTERMSIG
 # define WTERMSIG(w)	(((union wait *) &(w))->w_termsig)
 # ifndef BSDWAIT
@@ -91,23 +91,7 @@ static struct cvxrusage zru = {{0L, 0L}, {0L, 0L}, 0L, 0L, 0L, 0L,
 				{0L, 0L}, 0LL, 0LL, 0LL, 0LL, 0L, 0L, 0L,
 				0LL, 0LL, {0L, 0L, 0L, 0L, 0L}};
 # else
-#  if defined(SUNOS4) || defined(hp9000) || (defined(__alpha) && defined(__osf__))
-static struct rusage zru = {{0L, 0L}, {0L, 0L}, 0L, 0L, 0L, 0L,
-			    0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L, 0L};
-
-#  else /* !SUNOS4 && !hp9000 && !(__alpha && __osf__) */
-#   ifdef masscomp
-/*
- * Initialization of this structure under RTU 4.1A & RTU 5.0 is problematic
- * because the first two elements are unions of a time_t and a struct timeval.
- * So we'll just have to trust the loader to do the "right thing", DAS DEC-90.
- */
 static struct rusage zru;
-#   else	/* masscomp */
-static struct rusage zru = {{0L, 0L}, {0L, 0L}, 0, 0, 0, 0, 0, 0, 0, 
-			    0, 0, 0, 0, 0, 0};
-#   endif /* masscomp */
-#  endif	/* SUNOS4 || hp9000 || (__alpha && __osf__) */
 # endif /* convex */
 #else /* !BSDTIMES */
 # ifdef _SEQUENT_
@@ -146,7 +130,7 @@ static	void		 setttypgrp	__P((int));
  *	childs status.  Top level routines (like pwait) must be sure
  *	to mask interrupts when playing with the proclist data structures!
  */
-sigret_t
+RETSIGTYPE
 /*ARGSUSED*/
 pchild(snum)
 int snum;
@@ -213,7 +197,7 @@ loop:
         (setintr && (intty || insource) ? WNOHANG | WUNTRACED : WNOHANG), &ru);
 #   else
     /* both a wait3 and rusage */
-#    if !defined(BSDWAIT) || defined(NeXT) || defined(MACH) || defined(linux) || (defined(IRIS4D) && (__STDC__ || defined(FUNCPROTO)) && SYSVREL <= 3) || defined(__lucid) || defined(__osf__)
+#    if !defined(BSDWAIT) || defined(NeXT) || defined(MACH) || defined(linux) || defined(__GNU__) || defined(__GLIBC__) || (defined(IRIS4D) && (__STDC__ || defined(PROTOTYPES)) && SYSVREL <= 3) || defined(__lucid) || defined(__osf__)
     pid = wait3(&w,
        (setintr && (intty || insource) ? WNOHANG | WUNTRACED : WNOHANG), &ru);
 #    else /* BSDWAIT */
@@ -304,11 +288,7 @@ loop:
 	    goto loop;
 	}
 	pnoprocesses = pid == -1;
-#ifndef SIGVOID
-	return (0);
-#else /* !SIGVOID */
-	return;
-#endif /* !SIGVOID */
+	goto end;
     }
     for (pp = proclist.p_next; pp != NULL; pp = pp->p_next)
 	if (pid == pp->p_procid)
@@ -467,6 +447,8 @@ found:
 #if defined(BSDJOBS) || defined(HAVEwait3)
     goto loop;
 #endif /* BSDJOBS || HAVEwait3 */
+ end:
+    ;
 }
 
 void
@@ -1054,7 +1036,7 @@ pendjob()
 static int
 pprint(pp, flag)
     struct process *pp;
-    bool    flag;
+    int    flag;
 {
     int status, reason;
     struct process *tp;
@@ -1169,12 +1151,14 @@ pprint(pp, flag)
 			    && reason != SIGINT
 			    && (reason != SIGPIPE
 				|| (pp->p_flags & PPOU) == 0))) {
-			char *ptr;
+			const char *ptr;
 			char buf[1024];
 
-			if ((ptr = mesg[pp->p_reason & ASCII].pname) == NULL)
-			    xsnprintf(ptr = buf, sizeof(buf), "%s %d",
+			if ((ptr = mesg[pp->p_reason & ASCII].pname) == NULL) {
+			    xsnprintf(buf, sizeof(buf), "%s %d",
 				CGETS(17, 5, "Signal"), pp->p_reason & ASCII);
+			    ptr = buf;
+			}
 			xprintf(format, ptr);
 		    }
 		    else
@@ -1784,7 +1768,7 @@ pstart(pp, foregnd)
 
 void
 panystop(neednl)
-    bool    neednl;
+    int    neednl;
 {
     struct process *pp;
 
@@ -1901,7 +1885,7 @@ pfork(t, wanttty)
     int     wanttty;
 {
     int pid;
-    bool    ignint = 0;
+    int    ignint = 0;
     int     pgrp;
 #ifdef BSDSIGS
     sigmask_t omask = 0;
@@ -2008,12 +1992,12 @@ pfork(t, wanttty)
 	    (void) signal(SIGHUP, SIG_IGN);
 	if (t->t_dflg & F_NICE) {
 	    int nval = SIGN_EXTEND_CHAR(t->t_nice);
-#ifdef BSDNICE
+#ifdef HAVE_SETPRIORITY
 	    if (setpriority(PRIO_PROCESS, 0, nval) == -1 && errno)
 		    stderror(ERR_SYSTEM, "setpriority", strerror(errno));
-#else /* !BSDNICE */
+#else /* !HAVE_SETPRIORITY */
 	    (void) nice(nval);
-#endif /* !BSDNICE */
+#endif /* !HAVE_SETPRIORITY */
 	}
 #ifdef F_VER
         if (t->t_dflg & F_VER) {
