@@ -1,4 +1,4 @@
-/* $Header: /src/pub/tcsh/sh.sem.c,v 3.65 2004/11/21 04:35:22 christos Exp $ */
+/* $Header: /src/pub/tcsh/sh.sem.c,v 3.69 2005/01/18 20:24:51 christos Exp $ */
 /*
  * sh.sem.c: I/O redirections and job forking. A touchy issue!
  *	     Most stuff with builtins is incorrect
@@ -33,7 +33,7 @@
  */
 #include "sh.h"
 
-RCSID("$Id: sh.sem.c,v 3.65 2004/11/21 04:35:22 christos Exp $")
+RCSID("$Id: sh.sem.c,v 3.69 2005/01/18 20:24:51 christos Exp $")
 
 #include "tc.h"
 #include "tw.h"
@@ -50,13 +50,13 @@ RCSID("$Id: sh.sem.c,v 3.65 2004/11/21 04:35:22 christos Exp $")
 #endif /* CLOSE_ON_EXEC */
 
 #if defined(__sparc__) || defined(sparc)
-# if !defined(MACH) && SYSVREL == 0 && !defined(Lynx) && !defined(BSD4_4) && !defined(linux)
+# if !defined(MACH) && SYSVREL == 0 && !defined(Lynx) && !defined(BSD4_4) && !defined(linux) && !defined(__GNU__) && !defined(__GLIBC__)
 #  include <vfork.h>
-# endif /* !MACH && SYSVREL == 0 && !Lynx && !BSD4_4 && !linux */
+# endif /* !MACH && SYSVREL == 0 && !Lynx && !BSD4_4 && !glibc */
 #endif /* __sparc__ || sparc */
 
 #ifdef VFORK
-static	sigret_t	vffree	__P((int));
+static	RETSIGTYPE	vffree	__P((int));
 #endif 
 static	Char		*splicepipe	__P((struct command *, Char *));
 static	void		 doio		__P((struct command *, int *, int *));
@@ -88,9 +88,9 @@ execute(t, wanttty, pipein, pipeout, do_glob)
     struct command *t;
     int     wanttty;
     int *pipein, *pipeout;
-    bool do_glob;
+    int do_glob;
 {
-    bool    forked = 0;
+    int    forked = 0;
     struct biltins *bifunc;
     int     pid = 0;
     int     pv[2];
@@ -518,7 +518,7 @@ execute(t, wanttty, pipein, pipeout, do_glob)
 		else {		/* child */
 		    /* this is from pfork() */
 		    int     pgrp;
-		    bool    ignint = 0;
+		    int    ignint = 0;
 		    if (nosigchld) {
 # ifdef BSDSIGS
 			(void) sigsetmask(csigmask);
@@ -575,13 +575,13 @@ execute(t, wanttty, pipein, pipeout, do_glob)
 			(void) signal(SIGHUP, SIG_DFL);
 		    if (t->t_dflg & F_NICE) {
 			int nval = SIGN_EXTEND_CHAR(t->t_nice);
-# ifdef BSDNICE
+# ifdef HAVE_SETPRIORITY
 			if (setpriority(PRIO_PROCESS, 0, nval) == -1 && errno)
 				stderror(ERR_SYSTEM, "setpriority",
 				    strerror(errno));
-# else /* !BSDNICE */
+# else /* !HAVE_SETPRIORITY */
 			(void) nice(nval);
-# endif /* BSDNICE */
+# endif /* HAVE_SETPRIORITY */
 		    }
 # ifdef F_VER
 		    if (t->t_dflg & F_VER) {
@@ -754,7 +754,7 @@ execute(t, wanttty, pipein, pipeout, do_glob)
 }
 
 #ifdef VFORK
-static sigret_t
+static RETSIGTYPE
 /*ARGSUSED*/
 vffree(snum)
 int snum;
@@ -773,10 +773,6 @@ int snum;
     }
 
     _exit(1);
-#ifndef SIGVOID
-    /*NOTREACHED*/
-    return(0);
-#endif /* SIGVOID */
 }
 #endif /* VFORK */
 
