@@ -1,4 +1,4 @@
-/* $Header: /src/pub/tcsh/tc.func.c,v 3.113 2004/11/21 04:38:03 christos Exp $ */
+/* $Header: /src/pub/tcsh/tc.func.c,v 3.119 2005/03/06 03:57:10 christos Exp $ */
 /*
  * tc.func.c: New tcsh builtins.
  */
@@ -32,7 +32,7 @@
  */
 #include "sh.h"
 
-RCSID("$Id: tc.func.c,v 3.113 2004/11/21 04:38:03 christos Exp $")
+RCSID("$Id: tc.func.c,v 3.119 2005/03/06 03:57:10 christos Exp $")
 
 #include "ed.h"
 #include "ed.defns.h"		/* for the function names */
@@ -58,19 +58,19 @@ extern int do_logout;
 #endif /* TESLA */
 extern time_t t_period;
 extern int just_signaled;
-static bool precmd_active = 0;
-static bool jobcmd_active = 0; /* GrP */
-static bool postcmd_active = 0;
-static bool periodic_active = 0;
-static bool cwdcmd_active = 0;	/* PWP: for cwd_cmd */
-static bool beepcmd_active = 0;
+static int precmd_active = 0;
+static int jobcmd_active = 0; /* GrP */
+static int postcmd_active = 0;
+static int periodic_active = 0;
+static int cwdcmd_active = 0;	/* PWP: for cwd_cmd */
+static int beepcmd_active = 0;
 static signalfun_t alm_fun = NULL;
 
 static	void	 auto_logout	__P((int));
 static	char	*xgetpass	__P((const char *));
 static	void	 auto_lock	__P((int));
 #ifdef BSDJOBS
-static	void	 insert		__P((struct wordent *, bool));
+static	void	 insert		__P((struct wordent *, int));
 static	void	 insert_we	__P((struct wordent *, struct wordent *));
 static	int	 inlist		__P((Char *, Char *));
 #endif /* BSDJOBS */
@@ -78,7 +78,7 @@ struct tildecache;
 static	int	 tildecompare	__P((struct tildecache *, struct tildecache *));
 static  Char    *gethomedir	__P((Char *));
 #ifdef REMOTEHOST
-static	sigret_t palarm		__P((int));
+static	RETSIGTYPE palarm		__P((int));
 static	void	 getremotehost	__P((void));
 #endif /* REMOTEHOST */
 
@@ -137,6 +137,19 @@ expand_lex(buf, bufsiz, sp0, from, to)
     for (i = 0; i < NCARGS; i++) {
 	if ((i >= from) && (i <= to)) {	/* if in range */
 	    for (s = sp->word; *s && d < e; s++) {
+
+		if (s[1] & QUOTE) {
+		    int l = NLSSize(s, -1);
+		    if (l > 1) {
+			while (l-- > 0) {
+			    if (d < e)
+				*d++ = (*s & TRIM);
+			    prev_c = *s++;
+			}
+			s--;
+			continue;
+		    }
+		}
 		/*
 		 * bugfix by Michael Bloom: anything but the current history
 		 * character {(PWP) and backslash} seem to be dealt with
@@ -415,8 +428,7 @@ dolist(v, c)
     }
 }
 
-static const char *defaulttell = "ALL";
-extern bool GotTermCaps;
+extern int GotTermCaps;
 
 /*ARGSUSED*/
 void
@@ -424,18 +436,11 @@ dotelltc(v, c)
     Char **v;
     struct command *c;
 {
+    USE(v);
     USE(c);
     if (!GotTermCaps)
 	GetTermCaps();
-
-    /*
-     * Avoid a compiler bug on hpux 9.05
-     * Writing the following as func(a ? b : c) breaks
-     */
-    if (v[1])
-	TellTC(short2str(v[1]));
-    else
-	TellTC(defaulttell);
+    TellTC();
 }
 
 /*ARGSUSED*/
@@ -637,7 +642,7 @@ fg_proc_entry(pp)
     sigmask_t omask;
 #endif
     jmp_buf_t osetexit;
-    bool    ohaderr;
+    int    ohaderr;
     Char    oGettingInput;
 
     getexit(osetexit);
@@ -734,7 +739,7 @@ auto_lock(n)
 
 #undef XCRYPT
 
-#if defined(PW_AUTH) && !defined(XCRYPT)
+#if defined(HAVE_AUTH_H)
 
     struct authorization *apw;
     extern char *crypt16 __P((const char *, const char *));
@@ -745,9 +750,7 @@ auto_lock(n)
         (apw = getauthuid(euid)) != NULL) 	/* enhanced ultrix passwd */
 	srpp = apw->a_password;
 
-#endif /* PW_AUTH && !XCRYPT */
-
-#if defined(PW_SHADOW) && !defined(XCRYPT)
+#elif defined(HAVE_SHADOW_H)
 
     struct spwd *spw;
 
@@ -757,9 +760,7 @@ auto_lock(n)
 	(spw = getspnam(pw->pw_name)) != NULL)	/* shadowed passwd	  */
 	srpp = spw->sp_pwdp;
 
-#endif /* PW_SHADOW && !XCRYPT */
-
-#ifndef XCRYPT
+#else
 
 #define XCRYPT(a, b) crypt(a, b)
 
@@ -768,7 +769,7 @@ auto_lock(n)
 	srpp = pw->pw_passwd;
 #endif /* !MVS */
 
-#endif /* !XCRYPT */
+#endif
 
     if (srpp == NULL) {
 	auto_logout(0);
@@ -849,7 +850,7 @@ auto_logout(n)
     goodbye(NULL, NULL);
 }
 
-sigret_t
+RETSIGTYPE
 /*ARGSUSED*/
 alrmcatch(snum)
 int snum;
@@ -863,9 +864,6 @@ int snum;
     (*alm_fun)(0);
 
     setalarm(1);
-#ifndef SIGVOID
-    return (snum);
-#endif /* !SIGVOID */
 }
 
 /*
@@ -1189,6 +1187,17 @@ setalarm(lck)
     if ((vp = adrof(STRautologout)) != NULL && vp->vec != NULL) {
 	if ((cp = vp->vec[0]) != 0) {
 	    if ((logout_time = (unsigned) atoi(short2str(cp)) * 60) > 0) {
+#ifdef SOLARIS2
+		/*
+		 * Solaris alarm(2) uses a timer based in clock ticks
+		 * internally so it multiplies our value with CLK_TCK...
+		 * Of course that can overflow leading to unexpected
+		 * results, so we clip it here. Grr. Where is that
+		 * documented folks?
+		 */
+		if (logout_time >= 0x7fffffff / CLK_TCK)
+			logout_time = 0x7fffffff / CLK_TCK;
+#endif /* SOLARIS2 */
 		alrm_time = logout_time;
 		alm_fun = auto_logout;
 	    }
@@ -1340,7 +1349,7 @@ continue_jobs(cp)
     static Char STRcndebug[] =
     {'c', 'n', 'd', 'e', 'b', 'u', 'g', '\0'};
 #endif /* CNDEBUG */
-    bool    in_cont_list, in_cont_arg_list;
+    int    in_cont_list, in_cont_arg_list;
 
 
 #ifdef CNDEBUG
@@ -1402,7 +1411,7 @@ continue_jobs(cp)
 static void
 insert(pl, file_args)
     struct wordent *pl;
-    bool    file_args;
+    int    file_args;
 {
     struct wordent *now, *last;
     Char   *cmd, *bcmd, *cp1, *cp2;
@@ -1737,7 +1746,7 @@ doaliases(v, c)
     int     fd;
     Char    buf[BUFSIZE], line[BUFSIZE];
     char    tbuf[BUFSIZE + 1], *tmp;
-    extern bool output_raw;	/* PWP: in sh.print.c */
+    extern int output_raw;	/* PWP: in sh.print.c */
 
     USE(c);
     v++;
@@ -2083,7 +2092,7 @@ hashbang(fd, vp)
 
 #ifdef REMOTEHOST
 
-static sigret_t
+static RETSIGTYPE
 palarm(snum)
     int snum;
 {
@@ -2094,10 +2103,6 @@ palarm(snum)
 #endif /* UNRELSIGS */
     (void) alarm(0);
     reset();
-
-#ifndef SIGVOID
-    return (snum);
-#endif
 }
 
 
@@ -2112,9 +2117,9 @@ getremotehost()
 #else
     struct hostent* hp;
     struct sockaddr_in saddr;
-    int len = sizeof(struct sockaddr_in);
+    socklen_t len = sizeof(struct sockaddr_in);
 #endif
-#if defined(UTHOST) && !defined(HAVENOUTMP)
+#ifdef HAVE_STRUCT_UTMP_UT_HOST
     char *sptr = NULL;
 #endif
 
@@ -2141,7 +2146,7 @@ getremotehost()
 	    host = inet_ntoa(saddr.sin_addr);
 #endif
     }
-#if defined(UTHOST) && !defined(HAVENOUTMP)
+#ifdef HAVE_STRUCT_UTMP_UT_HOST
     else {
 	char *ptr;
 	char *name = utmphost();
@@ -2176,11 +2181,7 @@ getremotehost()
 		    hints.ai_family = PF_UNSPEC;
 		    hints.ai_socktype = SOCK_STREAM;
 		    hints.ai_flags = AI_PASSIVE | AI_CANONNAME;
-#if defined(UTHOST) && !defined(HAVENOUTMP)
 		    if (strlen(name) < utmphostsize())
-#else
-		    if (name != NULL)
-#endif
 		    {
 			if (getaddrinfo(name, NULL, &hints, &res) != 0)
 			    res = NULL;
@@ -2230,7 +2231,7 @@ getremotehost()
     if (host)
 	tsetenv(STRREMOTEHOST, str2short(host));
 
-#if defined(UTHOST) && !defined(HAVENOUTMP)
+#ifdef HAVE_STRUCT_UTMP_UT_HOST
     if (sptr)
 	*sptr = ':';
 #endif
