@@ -1,4 +1,4 @@
-/* $Header: /src/pub/tcsh/tc.os.h,v 3.91 2004/09/28 15:37:29 christos Exp $ */
+/* $Header: /src/pub/tcsh/tc.os.h,v 3.97 2005/03/03 22:32:01 kim Exp $ */
 /*
  * tc.os.h: Shell os dependent defines
  */
@@ -33,13 +33,6 @@
 #ifndef _h_tc_os
 #define _h_tc_os
 
-#ifndef __STDC__
-#ifndef WINNT_NATIVE
-#define NEEDstrerror		/* Too hard to find which systems have it */
-#endif /* WINNT_NATIVE */
-#endif
-
-
 #ifdef notdef 
 /*
  * for SVR4 and linux we used to fork pipelines backwards. 
@@ -52,7 +45,6 @@
 #ifdef __CYGWIN__
 #  undef NOFILE
 #  define NOFILE sysconf(_SC_OPEN_MAX)
-#  undef NEEDstrerror
 #endif
 
 #ifdef   _VMS_POSIX
@@ -60,8 +52,6 @@
 #  define  NOFILE 64
 # endif /* NOFILE */
 # define  nice(a)       setprio((getpid()),a)
-# undef   NEEDstrerror    /* won't get sensible error messages otherwise */
-# define  NEEDgethostname 
 # include <sys/time.h>    /* for time stuff in tc.prompt.c */
 # include <limits.h>
 #endif /* atp vmsposix */
@@ -86,17 +76,6 @@
 # define NOFILE 256
 #endif /* NOFILE */
 
-#if defined(linux) || defined(__NetBSD__) || defined(__FreeBSD__) || SYSVREL >= 4  || defined(_MINIX_VMD)
-# undef NEEDstrerror
-#endif /* linux || __NetBSD__ || __FreeBSD__ || SYSVREL >= 4 || _MINIX_VMD */
-
-#if !defined(pyr) && !defined(sinix)
-/* Pyramid's cpp complains about the next line */
-# if defined(BSD) && BSD >= 199306
-#  undef NEEDstrerror
-# endif /* BSD && BSD >= 199306 */
-#endif /* pyr */
-
 #ifdef OREO
 # include <sys/time.h>
 # ifdef notdef
@@ -161,12 +140,6 @@ struct ucred {
 #  include <sys/bsdtty.h>
 # endif /* !hp9000s500 && !(SIGRTMAX || SIGRTMIN) */
 
-# ifndef POSIX
-#  ifdef BSDJOBS
-#   define getpgrp(a) getpgrp2(a)
-#   define setpgrp(a, b) setpgrp2(a, b)
-#  endif /* BSDJOBS */
-# endif	/* POSIX */
 # ifndef TIOCSTI
 #  include <sys/strtio.h>
 # endif
@@ -197,10 +170,10 @@ struct ucred {
  * #if (SYSVREL > 0) && defined(TIOCGWINSZ)
  * If that breaks on your machine, let me know.
  *
- * It would break on linux, where all this is
+ * It would break on glibc, where all this is
  * defined in <termios.h>. Wrapper added.
  */
-#if !defined(linux) && !defined(_VMS_POSIX)
+#if !defined(linux) && !defined(__GNU__) && !defined(__GLIBC__) && !defined(_VMS_POSIX)
 # if defined(INTEL) || defined(u3b2) || defined (u3b5) || defined(ub15) || defined(u3b20d) || defined(ISC) || defined(SCO) || defined(tower32)
 #  ifdef TIOCGWINSZ
 /*
@@ -209,26 +182,12 @@ struct ucred {
 #   include <sys/stream.h>
 #   include <sys/ptem.h>
 #  endif /* TIOCGWINSZ */
-#  ifndef ODT
-#   define NEEDgethostname
-#  endif /* ODT */
 # endif /* INTEL || u3b2 || u3b5 || ub15 || u3b20d || ISC || SCO || tower32 */
-#endif /* !linux && !_VMS_POSIX */
-
-#if defined(UNIXPC) || defined(COHERENT)
-# define NEEDgethostname
-#endif /* UNIXPC || COHERENT */
+#endif /* !glibc && !_VMS_POSIX */
 
 #ifdef IRIS4D
 # include <sys/time.h>
 # include <sys/resource.h>
-# ifndef POSIX
-/*
- * BSDsetpgrp() and BSDgetpgrp() are BSD versions of setpgrp, etc.
- */
-#  define setpgrp BSDsetpgrp
-#  define getpgrp BSDgetpgrp
-# endif /* POSIX */
 #endif /* IRIS4D */
 
 /*
@@ -276,19 +235,7 @@ struct ucred {
 # endif /* S_IFMT */
 #endif /* ISC */
 
-#if defined(uts) || defined(UTekV) || defined(sysV88)
-/*
- * The uts 2.1.2 macros (Amdahl) are busted!
- * You should fix <sys/stat.h>, cause other programs will break too!
- *
- * From: creiman@ncsa.uiuc.edu (Charlie Reiman)
- */
-
-/*
- * The same applies to Motorola MPC (System V/88 R32V2, UTekV 3.2e) 
- * workstations, the stat macros are broken.
- * Kaveh Ghazi (ghazi@caip.rutgers.edu)
- */
+#ifdef STAT_MACROS_BROKEN
 # undef S_ISDIR
 # undef S_ISCHR
 # undef S_ISBLK
@@ -297,7 +244,7 @@ struct ucred {
 # undef S_ISNAM
 # undef S_ISLNK
 # undef S_ISSOCK
-#endif /* uts || UTekV || sysV88 */
+#endif /* STAT_MACROS_BROKEN */
 
 #ifdef S_IFMT
 # if !defined(S_ISDIR) && defined(S_IFDIR)
@@ -449,18 +396,11 @@ struct ucred {
 # endif /* SEEK_END */
 #endif /* L_XTND */
 
-#ifdef _SEQUENT_
-# define NEEDgethostname
-#endif /* _SEQUENT_ */
-
-#if defined(BSD) && defined(POSIXJOBS) && !defined(BSD4_4) && !defined(__hp_osf)
+#if !defined (HAVE_SETPGID) && !defined (SETPGRP_VOID)
 # define setpgid(pid, pgrp)	setpgrp(pid, pgrp)
-#endif /* BSD && POSIXJOBS && && !BSD4_4 && !__hp_osf */
+#endif
 
 #if defined(BSDJOBS) && !(defined(POSIX) && defined(POSIXJOBS))
-# if !defined(_AIX370) && !defined(_AIXPS2)
-#  define setpgid(pid, pgrp)	setpgrp(pid, pgrp)
-# endif /* !_AIX370 && !_AIXPS2 */
 # define NEEDtcgetpgrp
 #endif /* BSDJOBS && !(POSIX && POSIXJOBS) */
 
@@ -471,11 +411,6 @@ struct ucred {
 # define NEEDtcgetpgrp
 #endif /* RENO */
 
-#ifdef DGUX
-# define setpgrp(a, b) setpgrp2(a, b)
-# define getpgrp(a) getpgrp2(a)
-#endif /* DGUX */
-
 #ifdef SXA
 # ifndef _BSDX_
 /*
@@ -487,8 +422,6 @@ struct ucred {
 #endif /* SXA */
 
 #if defined(_MINIX) || defined(__EMX__)
-# define NEEDgethostname
-# define NEEDnice
 # define HAVENOLIMIT
 /*
  * Minix does not have these, so...
@@ -501,23 +434,6 @@ struct ucred {
 # define ttyname(fd) (isatty(fd) ? "/dev/tty" : NULL)
 #endif /* __EMX__ */
 
-#ifndef POSIX
-# define mygetpgrp()    getpgrp(0)
-#else /* POSIX */
-# if (defined(BSD) && !defined(BSD4_4)) || defined(SUNOS4) || defined(IRIS4D) || defined(DGUX) || defined(HPRT)
-#  define mygetpgrp()    getpgrp(0)
-# else /* !((BSD && !BSD4_4) || SUNOS4 || IRIS4D || DGUX || HPRT) */
-#  define mygetpgrp()    getpgrp()
-# endif	/* (BSD && BSD4_4) || SUNOS4 || IRISD || DGUX  || HPRT */
-#endif /* POSIX */
-
-
-#if !defined(SOLARIS2) && !defined(sinix) && !defined(BSD4_4) && !defined(WINNT_NATIVE)
-# if (SYSVREL > 0 && !defined(OREO) && !defined(sgi) && !defined(linux) && !defined(sinix) && !defined(_AIX) &&!defined(_UWIN)) || defined(NeXT)
-#  define NEEDgetcwd
-# endif /* (SYSVREL > 0 && !OREO && !sgi && !linux && !sinix && !_AIX && !_UWIN) || NeXT */
-#endif
-
 #ifndef S_IFLNK
 # define lstat stat
 #endif /* S_IFLNK */
@@ -537,12 +453,15 @@ typedef struct timeval timeval_t;
 # define free tcsh_free
 #endif /* NeXT */
 
-#if !defined(BSD4_4) && !defined(__linux__) && !defined(__hpux) && \
-    !defined(sgi) && !defined(_AIX) && !defined(__CYGWIN__)
-#ifndef NEEDgethostname
+#if defined(HAVE_GETHOSTNAME) && !HAVE_DECL_GETHOSTNAME
 extern int gethostname __P((char *, int));
-#endif /* NEEDgethostname */
-#endif /* !BDS4_4 && !__linux__ && !__hpux && !sgi */
+#endif
+
+#ifndef GETPGRP_VOID
+# define mygetpgrp()    getpgrp(0)
+#else
+# define mygetpgrp()    getpgrp()
+#endif
 
 #if !defined(POSIX) || defined(SUNOS4) || defined(UTekV) || defined(sysV88)
 extern time_t time();
@@ -552,6 +471,7 @@ extern int atoi();
 extern char *ttyname();
 # endif /* __EMX__ */
 
+
 # if defined(SUNOS4)
 #  ifndef toupper
 extern int toupper __P((int));
@@ -560,19 +480,9 @@ extern int toupper __P((int));
 extern int tolower __P((int));
 #  endif /* tolower */
 extern caddr_t sbrk __P((int));
-#  if SYSVREL == 0 && !defined(__lucid)
-extern int qsort();
-#  endif /* SYSVREL == 0 && !__lucid */
 # else /* !SUNOS4 */
 #  ifndef WINNT_NATIVE
-#   ifndef hpux
-#    if __GNUC__ != 2
-extern int abort();
-#    endif /* __GNUC__ != 2 */
-#    ifndef fps500
-extern int qsort();
-#    endif /* !fps500 */
-#   else /* !hpux */
+#   ifdef hpux
 extern void abort();
 extern void qsort();
 #   endif /* hpux */
@@ -583,12 +493,9 @@ extern void perror();
 #endif
 
 # ifdef BSDSIGS
-#  if defined(_AIX370) || defined(MACH) || defined(NeXT) || defined(_AIXPS2) || defined(ardent) || defined(SUNOS4) || defined(HPBSD) || defined(__MACHTEN__)
-extern int sigvec();
-extern int sigpause();
-#  else	/* !(_AIX370 || MACH || NeXT || _AIXPS2 || ardent || SUNOS4 || HPBSD) */
+#  if !defined(_AIX370) && !defined(MACH) && !defined(NeXT) && !defined(_AIXPS2) && !defined(ardent) && !defined(SUNOS4) && !defined(HPBSD) && !defined(__MACHTEN__)
 #   if (!defined(apollo) || !defined(__STDC__)) && !defined(__DGUX__) && !defined(fps500)
-extern sigret_t sigvec();
+extern RETSIGTYPE sigvec();
 #ifndef _CX_UX
 extern void sigpause();
 #endif /* _CX_UX */
@@ -598,14 +505,6 @@ extern sigmask_t sigblock();
 extern sigmask_t sigsetmask();
 # endif	/* BSDSIGS */
 
-# ifndef killpg
-extern int killpg();
-# endif	/* killpg */
-
-# ifndef lstat
-extern int lstat();
-# endif	/* lstat */
-
 # ifdef BSD
 extern uid_t getuid(), geteuid();
 extern gid_t getgid(), getegid();
@@ -618,47 +517,14 @@ extern memalign_t calloc();
 extern void free();
 # endif	/* SYSMALLOC */
 
-# ifdef BSDTIMES
-extern int getrlimit();
-extern int setrlimit();
-extern int getrusage();
-extern int gettimeofday();
-# endif	/* BSDTIMES */
-
-# if defined(NLS) && !defined(NOSTRCOLL) && !defined(NeXT)
-extern int strcoll();
-# endif /* NLS && !NOSTRCOLL && !NeXT */
-
 # ifdef BSDJOBS
 #  ifdef BSDTIMES
 #   ifdef __MACHTEN__
 extern pid_t wait3();
-#   else
-#   ifndef HPBSD
-extern int wait3();
-#   endif /* HPBSD */
 #   endif /* __MACHTEN__ */
-#  else	/* !BSDTIMES */
-#   if !defined(POSIXJOBS) && !defined(_SEQUENT_)
-extern int wait3();
-#   else /* POSIXJOBS || _SEQUENT_ */
-extern int waitpid();
-#   endif /* POSIXJOBS || _SEQUENT_ */
 #  endif /* BSDTIMES */
-# else /* !BSDJOBS */
-#  if SYSVREL < 3
-extern int ourwait();
-#  else	/* SYSVREL >= 3 */
-extern int wait();
-#  endif /* SYSVREL < 3 */
 # endif	/* BSDJOBS */
 
-# ifdef BSDNICE
-extern int setpriority();
-# else /* !BSDNICE */
-extern int nice();
-# endif	/* BSDNICE */
-
 # if (!defined(fps500) && !defined(apollo) && !defined(__lucid) && !defined(HPBSD) && !defined(DECOSF1))
 extern void setpwent();
 extern void endpwent();
@@ -666,12 +532,12 @@ extern void endpwent();
 
 # ifndef __STDC__
 extern struct passwd *getpwuid(), *getpwnam(), *getpwent();
-#  ifdef PW_SHADOW
+#  ifdef HAVE_SHADOW_H
 extern struct spwd *getspnam(), *getspent();
-#  endif /* PW_SHADOW */
-#  ifdef PW_AUTH
+#  endif /* HAVE_SHADOW_H */
+#  ifdef HAVE_AUTH_H
 extern struct authorization *getauthuid();
-#  endif /* PW_AUTH */
+#  endif /* HAVE_AUTH_H */
 # endif /* __STDC__ */
 
 # ifndef getcwd
@@ -717,17 +583,9 @@ extern void bcopy	__P((const void *, void *, size_t));
 # endif /* __alpha && __osf__ && DECOSF1 < 200 */
 #endif /* (BSD && !BSD4_4) || SUNOS4 */
 
-#if !defined(hpux) && !defined(COHERENT) && ((SYSVREL < 4) || defined(_SEQUENT_)) && !defined(BSD4_4) && !defined(memmove)
-# define NEEDmemmove
-#endif /* !hpux && !COHERENT && (SYSVREL < 4 || _SEQUENT_) && !BSD4_4 && !memmove */
-
-#if defined(UTek) || defined(pyr)
-# define NEEDmemset
-#else /* !UTek && !pyr */
-# ifdef SUNOS4
-#  include <memory.h>	/* memset should be declared in <string.h> but isn't */
-# endif /* SUNOS4 */
-#endif /* UTek || pyr */
+#ifdef SUNOS4
+# include <memory.h>	/* memset should be declared in <string.h> but isn't */
+#endif /* SUNOS4 */
 
 #if SYSVREL == 4
 # ifdef REMOTEHOST
@@ -744,18 +602,13 @@ extern int getpeername __P((int, struct sockaddr *, int *));
 extern int getrlimit __P((int, struct rlimit *));
 extern int setrlimit __P((int, const struct rlimit *));
 # endif /* !BSDTIMES */
-# if !defined(IRIS4D) && !defined(SOLARIS2)
-extern int wait3();	/* I think some bizarre systems still need this */
-# endif /* !IRIS4D && !SOLARIS2 */
 # if defined(SOLARIS2)
-#  undef NEEDstrerror
 extern char *strerror __P((int));
 # endif /* SOLARIS2 */
 #endif /* SYSVREL == 4 */
 
 #if defined(__alpha) && defined(__osf__) && DECOSF1 < 200
 /* These are ok for 1.3, but conflict with the header files for 2.0 */
-extern int gethostname __P((char *, int));
 extern char *sbrk __P((ssize_t));
 extern int ioctl __P((int, unsigned long, char *));
 extern pid_t vfork __P((void));
