@@ -1,4 +1,4 @@
-/* $Header: /src/pub/tcsh/tw.color.c,v 1.14 2004/08/04 17:12:32 christos Exp $ */
+/* $Header: /src/pub/tcsh/tw.color.c,v 1.18 2005/03/03 16:40:53 kim Exp $ */
 /*
  * tw.color.c: builtin color ls-F
  */
@@ -32,7 +32,7 @@
  */
 #include "sh.h"
 
-RCSID("$Id: tw.color.c,v 1.14 2004/08/04 17:12:32 christos Exp $")
+RCSID("$Id: tw.color.c,v 1.18 2005/03/03 16:40:53 kim Exp $")
 
 #include "tw.h"
 #include "ed.h"
@@ -98,10 +98,10 @@ static Extension *extensions = NULL;
 static size_t nextensions = 0;
 
 static char *colors = NULL;
-bool	     color_context_ls = FALSE;	/* do colored ls */
-static bool  color_context_lsmF = FALSE;	/* do colored ls-F */
+int	     color_context_ls = FALSE;	/* do colored ls */
+static int  color_context_lsmF = FALSE;	/* do colored ls-F */
 
-static bool getstring __P((char **, const Char **, Str *, int));
+static int getstring __P((char **, const Char **, Str *, int));
 static void put_color __P((Str *));
 static void print_color __P((Char *, size_t, Char));
 
@@ -134,7 +134,7 @@ set_color_context()
 
 /* getstring():
  */
-static  bool
+static  int
 getstring(dp, sp, pd, f)
     char        **dp;		/* dest buffer */
     const Char  **sp;		/* source buffer */
@@ -145,25 +145,21 @@ getstring(dp, sp, pd, f)
     char *d = *dp;
     eChar sc;
 
-    while (*s && (*s & CHAR) != f && (*s & CHAR) != ':') {
+    while (*s && (*s & CHAR) != (Char)f && (*s & CHAR) != ':') {
 	if ((*s & CHAR) == '\\' || (*s & CHAR) == '^') {
 	    if ((sc = parseescape(&s)) == CHAR_ERR)
 		return 0;
 	}
 	else
 	    sc = *s++ & CHAR;
-#ifdef WIDE_STRINGS
 	d += one_wctomb(d, sc);
-#else
-	*d++ = sc;
-#endif
     }
 
     pd->s = *dp;
     pd->len = (int) (d - *dp);
     *sp = s;
     *dp = d;
-    return *s == f;
+    return *s == (Char)f;
 }
 
 
@@ -177,7 +173,7 @@ parseLS_COLORS(value)
     size_t  i, len;
     const Char   *v;		/* pointer in value */
     char   *c;			/* pointer in colors */
-    Extension *e;		/* pointer in extensions */
+    Extension *volatile e;	/* pointer in extensions */
     jmp_buf_t osetexit;
 
     (void) &e;
@@ -236,8 +232,8 @@ parseLS_COLORS(value)
 	default:		/* :vl=color: */
 	    if (v[0] && v[1] && (v[2] & CHAR) == '=') {
 		for (i = 0; i < nvariables; i++)
-		    if (variables[i].variable[0] == (v[0] & CHAR) &&
-			variables[i].variable[1] == (v[1] & CHAR))
+		    if ((Char)variables[i].variable[0] == (v[0] & CHAR) &&
+			(Char)variables[i].variable[1] == (v[1] & CHAR))
 			break;
 		if (i < nvariables) {
 		    v += 3;
@@ -268,7 +264,7 @@ put_color(color)
 {
     size_t  i;
     const char   *c = color->s;
-    bool    original_output_raw = output_raw;
+    int    original_output_raw = output_raw;
 
     output_raw = TRUE;
     for (i = color->len; 0 < i; i--)
@@ -302,7 +298,7 @@ print_color(fname, len, suffix)
     default:
 	for (i = 0; i < nvariables; i++)
 	    if (variables[i].suffix != NOS &&
-		variables[i].suffix == suffix) {
+		(Char)variables[i].suffix == suffix) {
 		color = &variables[i].color;
 		break;
 	    }
@@ -346,7 +342,7 @@ print_with_color(filename, len, suffix)
 	}
     }
     else
-	xprintf("\045S", filename);
+	xprintf("%S", filename);
     xputwchar(suffix);
 }
 
