@@ -1,4 +1,4 @@
-/* $Header: /src/pub/tcsh/tw.init.c,v 3.31 2004/08/08 06:42:29 christos Exp $ */
+/* $Header: /src/pub/tcsh/tw.init.c,v 3.34 2005/01/05 16:06:15 christos Exp $ */
 /*
  * tw.init.c: Handle lists of things to complete
  */
@@ -32,20 +32,13 @@
  */
 #include "sh.h"
 
-RCSID("$Id: tw.init.c,v 3.31 2004/08/08 06:42:29 christos Exp $")
+RCSID("$Id: tw.init.c,v 3.34 2005/01/05 16:06:15 christos Exp $")
 
 #include "tw.h"
 #include "ed.h"
 #include "tc.h"
 #include "sh.proc.h"
 
-#if !defined(NSIG) && defined(SIGMAX)
-# define NSIG (SIGMAX+1)
-#endif /* !NSIG && SIGMAX */
-#if !defined(NSIG) && defined(_NSIG)
-# define NSIG _NSIG
-#endif /* !NSIG && _NSIG */
-
 #define TW_INCR	128
 
 typedef struct {
@@ -150,7 +143,7 @@ tw_str_add(sl, len)
 		    (Char *) xmalloc((size_t) (sl->tbuff * sizeof(Char)));
 	/* Re-thread the new pointer list, if changed */
 	if (ptr != NULL && ptr != sl->buff) {
-	    int offs = (int) (sl->buff - ptr);
+	    intptr_t offs = sl->buff - ptr;
 	    for (i = 0; i < sl->nlist; i++)
 		sl->list[i] += offs;
 	}
@@ -638,9 +631,9 @@ tw_logname_start(dfd, pat)
 {
     USE(pat);
     SETDIR(dfd)
-#if !defined(_VMS_POSIX) && !defined(WINNT_NATIVE)
+#ifdef HAVE_GETPWENT
     (void) setpwent();	/* Open passwd file */
-#endif /* !_VMS_POSIX && !WINNT_NATIVE */
+#endif
 } /* end tw_logname_start */
 
 
@@ -664,12 +657,11 @@ tw_logname_next(dir, flags)
     USE(flags);
     USE(dir);
     TW_HOLD();
-#if !defined(_VMS_POSIX) && !defined(WINNT_NATIVE)
-    /* ISC does not declare getpwent()? */
-    pw = (struct passwd *) getpwent();
-#else /* _VMS_POSIX || WINNT_NATIVE */
+#ifdef HAVE_GETPWENT
+    pw = getpwent();
+#else
     pw = NULL;
-#endif /* !_VMS_POSIX && !WINNT_NATIVE */
+#endif
     TW_RELS();
 
     if (pw == NULL) {
@@ -692,9 +684,9 @@ tw_logname_end()
 #ifdef YPBUGS
     fix_yp_bugs();
 #endif
-#if !defined(_VMS_POSIX) && !defined(WINNT_NATIVE)
+#ifdef HAVE_GETPWENT
    (void) endpwent();
-#endif /* !_VMS_POSIX && !WINNT_NATIVE */
+#endif
 } /* end tw_logname_end */
 
 
